@@ -1,8 +1,11 @@
-scaleNumCol <- function(tabCol, IQR_bias) {
+scaleNumCol <- function(tabCol, IQR_bias, compare=FALSE) {
 	## for "auto" scales, choose between "lin" and "log" based on IQR_bias
 	if (tabCol$scale_init=="auto") {
-		quant <- quantile(tabCol$mean, na.rm=TRUE)
-		IQR <- quant[4] - quant[2]
+		if (compare) {
+			quant <- quantile(tabCol$mean.diff, na.rm=TRUE)
+		} else {
+			quant <- quantile(tabCol$mean, na.rm=TRUE)
+		}
 		
 		if (all(is.na(quant))) {
 			tabCol$scale_final <- "lin"
@@ -10,8 +13,10 @@ scaleNumCol <- function(tabCol, IQR_bias) {
 			IQR <- quant[4] - quant[2]
 			
 			## simple test to determine whether scale is lin or log
-			tabCol$scale_final <- ifelse(((quant[5] > quant[4] + IQR_bias * IQR) || 
-										  	(quant[1] < quant[2] - IQR_bias * IQR)), "log", "lin")
+			tabCol$scale_final <- 
+				ifelse(((quant[5]>0 && quant[5] > quant[4] + IQR_bias * IQR) || 
+							(quant[1]<0 && quant[1] < quant[2] - IQR_bias * IQR)), 
+										 "log", "lin")
 		}
 	} else {
 		tabCol$scale_final <- tabCol$scale_init
@@ -19,10 +24,19 @@ scaleNumCol <- function(tabCol, IQR_bias) {
 	
 	## apply transformation
 	if (tabCol$scale_final=="log") {
-		tabCol$mean.scaled <- getLog(tabCol$mean)
+		if (compare) {
+			tabCol$mean.diff.scaled <- getLog(tabCol$mean.diff)
+		} else {
+			tabCol$mean.scaled <- getLog(tabCol$mean)
+		}
 	} else {
-		tabCol$mean.scaled <- tabCol$mean
+		if (compare) {
+			tabCol$mean.diff.scaled <- tabCol$mean.diff
+		} else {
+			tabCol$mean.scaled <- tabCol$mean
+		}
 	}
+	if (compare) tabCol$mean.diff.rel.scaled <- tabCol$mean.diff.rel
 	tabCol
 }
 
