@@ -1,16 +1,10 @@
-#' Function to check the tableplot argument: sortCol
-#'
-#' @aliases tableplot_checkCols
-#' @param sortCol sortCol
-#' @param colNames colNames
-#' @return (possibly corrected) sortCol
-#' @export
 tableplot_checkCols <- function(sortCol, colNames) {	
 	if (!missing(sortCol)) {
 		nl <- as.list(seq_along(colNames))
 		names(nl) <- colNames
 		sortCol <- eval(sortCol, nl, parent.frame())
 		if (is.character(sortCol)) sortCol <- which(sortCol==colNames)
+		if (!length(sortCol)) stop("Incorrect sortCol argument")
 	}
 	
 	tryCatch({
@@ -19,6 +13,6 @@ tableplot_checkCols <- function(sortCol, colNames) {
 		if (getOption("show.error.messages")) cat("Incorrect sortCol argument\n")
 	})
 	
-	
-	return(sortCol)
+	if (length(sortCol)>1) warning("Sorting on multiple columns not supported anymore. Only first column is taken.")
+	sortCol[1]
 }
